import requests
import urllib.parse

def pd(message, model="openai"):
    encoded = urllib.parse.quote(message)
    url = f"https://text.pollinations.ai/{encoded}?model={model}"
    try:
        response = requests.get(url)
        response.raise_for_status()
        text = response.text.strip()
        print(text)
        return None
    except requests.exceptions.RequestException as e:
        print(f"Error: {e}")
        return None




from setuptools import setup, find_packages

setup(
    name='pundass',
    version='0.1.0',
    description='hi',
    author='Semban2690',
    author_email='aaro@gmail.com',
    packages=find_packages(),
    install_requires=[
        'requests',
    ],
    python_requires='>=2.1',
)

